@@ -33,32 +33,70 @@ from vega.cli.scaffolds import create_fastapi_scaffold
 from vega.cli.utils import to_snake_case, to_pascal_case
 
 
+def _has_bounded_context_root(project_root: Path) -> bool:
+    """Return True if the project contains a bounded-context root (lib/ or <pkg_name>/)."""
+    normalized_name = project_root.name.replace('-', '_')
+    return (project_root / "lib").exists() or (project_root / normalized_name).exists()
+
+
+def _find_project_root(start_path: Path) -> Path | None:
+    """
+    Walk upwards from start_path until a directory containing config.py is found.
+    Returns None if not found.
+    """
+    current = start_path
+    while True:
+        if (current / "config.py").exists():
+            return current
+        if current.parent == current:
+            # Reached filesystem root
+            return None
+        current = current.parent
+
+
 def _detect_bounded_context(project_root: Path) -> str | None:
     """
-    Detect which bounded context we're in based on current directory or prompt user.
+    Detect which bounded context we're in based on current directory or by prompting the user.
 
-    Returns:
-        Context name if found, None if lib/ doesn't exist (legacy structure)
+    Supports both legacy lib/ structure and the new package-based layout
+    (<project_name>/<context>/...). If no bounded-context root is present,
+    returns None to allow legacy flat projects.
     """
+    normalized_name = project_root.name.replace('-', '_')
     lib_path = project_root / "lib"
-    if not lib_path.exists():
-        return None  # Legacy structure
+    package_path = project_root / normalized_name
+
+    # Collect potential context roots (prefer package layout)
+    context_roots: list[Path] = []
+    if package_path.exists():
+        context_roots.append(package_path)
+    if lib_path.exists():
+        context_roots.append(lib_path)
+
+    if not context_roots:
+        return None  # Legacy flat structure
 
     # Try to detect context from current working directory
-    try:
-        cwd = Path.cwd()
-        relative = cwd.relative_to(lib_path)
-        if relative.parts:
-            return relative.parts[0]
-    except (ValueError, IndexError):
-        pass
+    cwd = Path.cwd()
+    for root in context_roots:
+        try:
+            relative = cwd.relative_to(root)
+            if relative.parts:
+                return relative.parts[0]
+        except (ValueError, IndexError):
+            continue
 
-    # Prompt user to select context
-    contexts = [d.name for d in lib_path.iterdir()
-                if d.is_dir() and not d.name.startswith('_') and d.name != 'shared']
+    # Build available contexts list (deduplicated, preserve order)
+    contexts: list[str] = []
+    for root in context_roots:
+        for d in root.iterdir():
+            if d.is_dir() and not d.name.startswith('_') and d.name != 'shared':
+                if d.name not in contexts:
+                    contexts.append(d.name)
 
     if not contexts:
-        click.echo(click.style("ERROR: No bounded contexts found in lib/", fg='red'))
+        root_hint = package_path if package_path.exists() else lib_path
+        click.echo(click.style(f"ERROR: No bounded contexts found in {root_hint.name}/", fg='red'))
         click.echo("Create a context first with: vega generate context <name>")
         return None
 
@@ -91,6 +129,13 @@ def _get_context_base_path(project_root: Path, context: str | None) -> Path:
     """
     if context is None:
         return project_root  # Legacy structure
+
+    normalized_name = project_root.name.replace('-', '_')
+    package_path = project_root / normalized_name / context
+    if package_path.exists():
+        return package_path
+
+    # Fallback to legacy lib/ structure
     return project_root / "lib" / context
 
 
@@ -120,12 +165,14 @@ def generate_component(
 ):
     """Generate a component in the Vega project"""
 
-    project_root = Path(project_path).resolve()
+    start_path = Path(project_path).resolve()
+    project_root = _find_project_root(start_path)
 
     # Check if we're in a Vega project
-    if not (project_root / "config.py").exists():
+    if project_root is None:
         click.echo(click.style("ERROR: Error: Not a Vega project (config.py not found)", fg='red'))
-        click.echo("   Run this command from your project root, or use --path option")
+        click.echo(f"   Path checked: {start_path}")
+        click.echo("   Run this command from your project root, or point --path to the project")
         return
 
     # Get project name from directory
@@ -182,9 +229,9 @@ def generate_component(
         if implementation and implementation.lower() == 'cli':
             _generate_command(project_root, project_name, name, None)
         else:
-            _generate_interactor(project_root, project_name, class_name, file_name, 'COMMAND')
+            _generate_interactor(project_root, project_name, class_name, file_name, 'command')
     elif component_type == 'query':
-        _generate_interactor(project_root, project_name, class_name, file_name, 'QUERY')
+        _generate_interactor(project_root, project_name, class_name, file_name, 'query')
     # Existing generators
     elif component_type == 'entity':
         _generate_entity(project_root, project_name, class_name, file_name)
@@ -220,7 +267,7 @@ def generate_component(
 def _generate_entity(project_root: Path, project_name: str, class_name: str, file_name: str):
     """Generate domain entity (context-aware)"""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown
 
     base_path = _get_context_base_path(project_root, context)
@@ -246,7 +293,7 @@ def _generate_repository(
 ):
     """Generate repository interface (context-aware)"""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown
 
     base_path = _get_context_base_path(project_root, context)
@@ -312,7 +359,7 @@ def _generate_service(
 ):
     """Generate service interface (context-aware)"""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown
 
     base_path = _get_context_base_path(project_root, context)
@@ -348,6 +395,12 @@ def _generate_service(
 def _generate_interactor(project_root: Path, project_name: str, class_name: str, file_name: str, cqrs_type: str | None = None):
     """Generate interactor (use case) with CQRS pattern"""
 
+    # Detect bounded context so generated files land in the right folder
+    context = _detect_bounded_context(project_root)
+    if context is None and _has_bounded_context_root(project_root):
+        return  # Error already shown by detector
+    base_path = _get_context_base_path(project_root, context)
+
     # If no CQRS type specified, ask the user
     if not cqrs_type:
         cqrs_type = click.prompt(
@@ -356,15 +409,18 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
             default='command'
         ).lower()
 
+    # Normalize type
+    cqrs_type = cqrs_type.lower()
+
     # Determine layer folder (commands or queries)
     layer_folder = 'commands' if cqrs_type == 'command' else 'queries'
     handler_type = 'COMMAND' if cqrs_type == 'command' else 'QUERY'
 
-    # Folder name for the interactor (e.g., CreateUser - keep PascalCase)
-    folder_name = class_name
+    # Folder name for the interactor (snake_case)
+    folder_name = file_name
 
     # Create the interactor directory
-    interactor_dir = project_root / "application" / layer_folder / class_name
+    interactor_dir = base_path / "application" / layer_folder / folder_name
 
     if interactor_dir.exists():
         click.echo(click.style(f"ERROR: Error: {interactor_dir.relative_to(project_root)} already exists", fg='red'))
@@ -373,10 +429,13 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
     interactor_dir.mkdir(parents=True, exist_ok=True)
 
     # Prepare file names and class names
-    input_file = f"{cqrs_type}"  # command.py or query.py
-    input_class = f"{class_name}{cqrs_type.capitalize()}"  # CreateUserCommand or GetUserQuery
+    input_file = f"{file_name}_{cqrs_type}"  # e.g., create_user_command.py
+    if cqrs_type == 'query':
+        input_class = f"{class_name}{cqrs_type}"  # lower suffix for queries
+    else:
+        input_class = f"{class_name}{cqrs_type.capitalize()}"  # CreateUserCommand
     input_var = cqrs_type  # command or query
-    response_file = "response"
+    response_file = f"{file_name}_response"
     response_class = f"{class_name}Result"
 
     # Ask for description
@@ -395,7 +454,7 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
         response_class=response_class,
         description=description,
     )
-    handler_file = interactor_dir / "handler.py"
+    handler_file = interactor_dir / f"{file_name}_handler.py"
     handler_file.write_text(handler_content)
     click.echo(f"+ Created {click.style(str(handler_file.relative_to(project_root)), fg='green')}")
 
@@ -403,7 +462,7 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
     if cqrs_type == 'command':
         input_content = render_cqrs_command(class_name, description)
     else:
-        input_content = render_cqrs_query(class_name, description)
+        input_content = render_cqrs_query(input_class, class_name, description)
 
     input_file_path = interactor_dir / f"{input_file}.py"
     input_file_path.write_text(input_content)
@@ -411,15 +470,15 @@ def _generate_interactor(project_root: Path, project_name: str, class_name: str,
 
     # Generate response.py
     response_content = render_cqrs_response(class_name, description)
-    response_file_path = interactor_dir / "response.py"
+    response_file_path = interactor_dir / f"{response_file}.py"
     response_file_path.write_text(response_content)
     click.echo(f"+ Created {click.style(str(response_file_path.relative_to(project_root)), fg='green')}")
 
     # Create __init__.py for easier imports
     init_content = f'''"""{ class_name} {cqrs_type} - CQRS Pattern"""
-from .handler import {class_name}Handler
+from .{file_name}_handler import {class_name}Handler
 from .{input_file} import {input_class}
-from .response import {response_class}
+from .{response_file} import {response_class}
 
 __all__ = [
     "{class_name}Handler",
@@ -432,8 +491,13 @@ __all__ = [
     click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
 
     # Usage instructions
+    # Build import path reflecting bounded context (if any)
+    if base_path == project_root:
+        app_module = "application"
+    else:
+        app_module = f"{base_path.relative_to(project_root).as_posix().replace('/', '.')}.application"
     click.echo(f"\nUsage:")
-    click.echo(f"   from application.{layer_folder}.{class_name} import {class_name}Handler, {input_class}")
+    click.echo(f"   from {app_module}.{layer_folder}.{folder_name} import {class_name}Handler, {input_class}")
     click.echo(f"   {input_var} = {input_class}(...)  # Add your parameters")
     click.echo(f"   result = await {class_name}Handler({input_var})")
 
@@ -906,31 +970,31 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
         from vega.cli.templates import render_cli_commands_init
         init_file.write_text(render_cli_commands_init())
         click.echo(f"+ Created {click.style(str(init_file.relative_to(project_root)), fg='green')}")
-    
+
     # Convert name to snake_case for command and file
     command_name = to_snake_case(name).replace('_', '-')
     file_name = to_snake_case(name)
-    
+
     # Generate command file
     command_file = commands_path / f"{file_name}.py"
-    
+
     if command_file.exists():
         click.echo(click.style(f"ERROR: Error: {command_file.relative_to(project_root)} already exists", fg='red'))
         return
-    
+
     # Determine if async (default is async unless explicitly set to 'sync' or 'simple')
     use_async = is_async not in ['sync', 'simple', 'false', 'no'] if is_async else True
-    
+
     # Prompt for command details
     description = click.prompt("Command description", default=f"{name} command")
-    
+
     # Ask if user wants to add options/arguments
     add_params = click.confirm("Add options or arguments?", default=False)
-    
+
     options = []
     arguments = []
     params_list = []
-    
+
     if add_params:
         click.echo("\nAdd options (e.g., --name, --email). Press Enter when done.")
         while True:
@@ -940,9 +1004,9 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
             opt_type = click.prompt("Type", default="str", type=click.Choice(['str', 'int', 'bool']))
             opt_required = click.confirm("Required?", default=False)
             opt_help = click.prompt("Help text", default=f"{opt_name.replace('-', ' ').replace('_', ' ')}")
-            
+
             params_list.append(opt_name.replace('-', '_'))
-            
+
             opt_params = f"help='{opt_help}'"
             if opt_required:
                 opt_params += ", required=True"
@@ -951,29 +1015,29 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
                     opt_params += ", is_flag=True"
                 else:
                     opt_params += f", type={opt_type}"
-            
+
             options.append({
                 "flag": f"--{opt_name}",
                 "params": opt_params
             })
-        
+
         click.echo("\nAdd arguments (positional). Press Enter when done.")
         while True:
             arg_name = click.prompt("Argument name", default="", show_default=False)
             if not arg_name:
                 break
             arg_required = click.confirm("Required?", default=True)
-            
+
             params_list.append(arg_name)
-            
+
             arg_params = "" if arg_required else ", required=False"
             arguments.append({
                 "name": arg_name,
                 "params": arg_params
             })
-    
+
     params_signature = ", ".join(params_list) if params_list else ""
-    
+
     # Ask about interactor usage
     with_interactor = False
     interactor_name = ""
@@ -981,11 +1045,11 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
         with_interactor = click.confirm("Will this command use an interactor?", default=True)
         if with_interactor:
             interactor_name = click.prompt("Interactor name", default=f"{to_pascal_case(name)}")
-    
+
     usage_example = f"python main.py {command_name}"
     if params_list:
         usage_example += " " + " ".join([f"--{p.replace('_', '-')}=value" if f"--{p.replace('_', '-')}" in str(options) else p for p in params_list])
-    
+
     # Generate content
     if use_async:
         content = render_cli_command(
@@ -1008,10 +1072,10 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
             params_signature=params_signature,
             params_list=params_list,
         )
-    
+
     command_file.write_text(content)
     click.echo(f"+ Created {click.style(str(command_file.relative_to(project_root)), fg='green')}")
-    
+
     # Instructions for next steps
     click.echo(f"\nNext steps:")
     click.echo(f"   1. Implement your command logic in {command_file.relative_to(project_root)}")
@@ -1024,7 +1088,7 @@ def _generate_command(project_root: Path, project_name: str, name: str, is_async
 def _generate_event(project_root: Path, project_name: str, class_name: str, file_name: str):
     """Generate a domain event (context-aware)."""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown
 
     base_path = _get_context_base_path(project_root, context)
@@ -1178,14 +1242,17 @@ def _generate_listener(project_root: Path, project_name: str, class_name: str, f
 
 
 def _generate_context(project_root: Path, project_name: str, context_name: str):
-    """Generate bounded context structure under lib/"""
-    lib_path = project_root / "lib"
-    if not lib_path.exists():
-        click.echo(click.style("ERROR: lib/ directory not found. This project uses legacy structure.", fg='red'))
+    """Generate bounded context structure under package directory"""
+    # Use normalized project name as package directory
+    normalized_name = project_name.replace('-', '_')
+    package_path = project_root / normalized_name
+
+    if not package_path.exists():
+        click.echo(click.style(f"ERROR: {normalized_name}/ directory not found. This project uses legacy structure.", fg='red'))
         click.echo("Create a new project with `vega init` to use DDD bounded contexts.")
         return
 
-    context_path = lib_path / context_name
+    context_path = package_path / context_name
     if context_path.exists():
         click.echo(click.style(f"ERROR: Context '{context_name}' already exists", fg='red'))
         return
@@ -1212,6 +1279,22 @@ def _generate_context(project_root: Path, project_name: str, context_name: str):
         dir_path.mkdir(parents=True, exist_ok=True)
         click.echo(f"  + Created {context_name}/{directory}/")
 
+    # Create test scaffolding per bounded context to keep tests co-located
+    tests_base = project_root / "tests" / normalized_name / context_name
+    test_dirs = [
+        "domain",
+        "application",
+        "infrastructure",
+        "presentation",
+    ]
+    for test_dir in test_dirs:
+        path = tests_base / test_dir
+        path.mkdir(parents=True, exist_ok=True)
+        init_file = path / "__init__.py"
+        if not init_file.exists():
+            init_file.write_text("")
+        click.echo(f"  + Created tests/{normalized_name}/{context_name}/{test_dir}/")
+
     # Initialize web package files
     from vega.cli.templates import (
         render_web_package_init,
@@ -1244,7 +1327,7 @@ def _generate_context(project_root: Path, project_name: str, context_name: str):
 def _generate_aggregate(project_root: Path, project_name: str, class_name: str, file_name: str):
     """Generate aggregate root in domain/aggregates/"""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown by _detect_bounded_context
 
     base_path = _get_context_base_path(project_root, context)
@@ -1255,7 +1338,12 @@ def _generate_aggregate(project_root: Path, project_name: str, class_name: str,
     else:
         # Legacy: create in domain/entities (no aggregates folder in legacy)
         file_path = base_path / "domain" / "entities" / f"{file_name}.py"
-        click.echo(click.style("WARNING: Using legacy structure. Consider migrating to lib/ structure.", fg='yellow'))
+        click.echo(
+            click.style(
+                "WARNING: Using legacy structure. Consider migrating to bounded contexts (project_name/<context>/...).",
+                fg='yellow'
+            )
+        )
 
     if file_path.exists():
         click.echo(click.style(f"ERROR: {file_path} already exists", fg='red'))
@@ -1277,7 +1365,7 @@ def _generate_aggregate(project_root: Path, project_name: str, class_name: str,
 def _generate_value_object(project_root: Path, project_name: str, class_name: str, file_name: str):
     """Generate value object in domain/value_objects/"""
     context = _detect_bounded_context(project_root)
-    if context is None and (project_root / "lib").exists():
+    if context is None and _has_bounded_context_root(project_root):
         return  # Error already shown
 
     base_path = _get_context_base_path(project_root, context)
